@@ -6,6 +6,7 @@ from sqlalchemy.dialects.postgresql.base import PGDialect
 from sqlalchemy.dialects.postgresql import INET
 from sqlalchemy.dialects.postgresql import UUID
 from sqlalchemy.ext.compiler import compiles
+from sqlalchemy.util import asbool
 from sqlalchemy.util import warn
 import sqlalchemy.sql as sql
 
@@ -96,16 +97,11 @@ class CockroachDBDialect(PGDialect):
     # Override connect so we can take disable_cockroachdb_telemetry as a connect_arg to sqlalchemy.
     def connect(
         self,
-        dsn=None,
-        connection_factory=None,
-        cursor_factory=None,
         disable_cockroachdb_telemetry=False,
         **kwargs,
     ):
-        self.disable_cockroachdb_telemetry = disable_cockroachdb_telemetry
-        return super().connect(
-            dsn, connection_factory,
-            cursor_factory, **kwargs)
+        self.disable_cockroachdb_telemetry = asbool(disable_cockroachdb_telemetry)
+        return super().connect(**kwargs)
 
     def __init__(self, *args, **kwargs):
         if kwargs.get("use_native_hstore", False):
@@ -148,8 +144,14 @@ class CockroachDBDialect(PGDialect):
         # The crdb_internal.increment_feature_counter only exists in v21.1 of CRDB
         # and onwards.
         if self._is_v211plus and not self.disable_cockroachdb_telemetry:
+            sqlalchemy_version_string = ""
             dialect_version = pkg_resources.require("sqlalchemy-cockroachdb")[0].version
             sqlalchemy_version = pkg_resources.require("sqlalchemy")[0].version
+            matches = re.findall(r"(\d+\.\d+)(\.|$)", sqlalchemy_version)
+            if len(matches) == 0:
+                sqlalchemy_version_string = sqlalchemy_version
+            else:
+                sqlalchemy_version_string = matches[0][0]
             telemetry_query = "SELECT crdb_internal.increment_feature_counter(:val)"
             connection.execute(
                 text(telemetry_query),
@@ -157,7 +159,7 @@ class CockroachDBDialect(PGDialect):
             )
             connection.execute(
                 text(telemetry_query),
-                dict(val=f'sqlalchemy {sqlalchemy_version}')
+                dict(val=f'sqlalchemy {sqlalchemy_version_string}')
             )
 
     def _get_server_version_info(self, conn):
